@@ -10,12 +10,10 @@ from typing import List
 
 from sdmxthon.model.utils import string_setter, bool_setter, generic_setter, \
     set_date_from_string
-from sdmxthon.parsers.data_parser import DataParser
-from sdmxthon.utils.mappings import Locale_Codes, commonAbbr
-from sdmxthon.utils.xml_base import find_attr_value_
+from sdmxthon.utils.mappings import commonAbbr
 
 
-class LocalisedString(DataParser):
+class LocalisedString(object):
     """The Localised String supports the representation
        of text in one locale (locale is similar to language but
        includes geographic variations such as Canadian
@@ -23,10 +21,9 @@ class LocalisedString(DataParser):
     """
 
     def __init__(self, locale: str = None, label: str = None,
-                 content: str = None, gds_collector=None):
+                 content: str = None):
         """Inits LocalisedString with optional attributes."""
 
-        super().__init__(gds_collector)
         self.label = label
         self._locale = locale
         self._content = content
@@ -36,13 +33,7 @@ class LocalisedString(DataParser):
             return (self._locale == other._locale and
                     self._content == other._content and
                     self._label == other._label)
-        else:
-            return False
-
-    @staticmethod
-    def _factory(*args):
-        """Factory Method of LocalisedString"""
-        return LocalisedString(*args)
+        return False
 
     @property
     def locale(self):
@@ -75,20 +66,6 @@ class LocalisedString(DataParser):
     def content(self, value):
         self._content = string_setter(value)
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        value = find_attr_value_('{http://www.w3.org/XML/1998/namespace}lang',
-                                 node)
-        if value is not None and 'lang' not in already_processed:
-            already_processed.add('lang')
-            self._label = value
-            if value in Locale_Codes.keys():
-                self._locale = Locale_Codes[value]
-            else:
-                raise ValueError(f'{value} is not in ISO 639-1 Codes')
-        if node.text.strip() not in ['', '\n']:
-            self._content = " ".join(node.text.split())
-
 
 class InternationalString(object):
     """The International String is a collection of Localised
@@ -107,8 +84,7 @@ class InternationalString(object):
     def __eq__(self, other):
         if isinstance(other, InternationalString):
             return self._items == other._items
-        else:
-            return False
+        return False
 
     @property
     def items(self):
@@ -120,10 +96,9 @@ class InternationalString(object):
         if not isinstance(localisedString, LocalisedString):
             raise TypeError("International strings can only get localised "
                             "strings as arguments")
-        else:
-            self._items[localisedString.label] = {
-                'locale': localisedString.locale,
-                'content': localisedString.content}
+        self._items[localisedString.label] = {
+            'locale': localisedString.locale,
+            'content': localisedString.content}
 
     def getLabels(self):
         """Gets the labels of the items present in the International String"""
@@ -145,20 +120,20 @@ class InternationalString(object):
         outfile = []
         if len(self._items) > 0:
             for label, v in self._items.items():
+                text = v["content"].replace("&", "&amp;") \
+                    .replace("<", "&lt;").replace(">", "&gt;")
                 outfile.append(
                     f'{child1}<{name} xml:lang="{label}">'
-                    f'{v["content"].replace("&", "&amp;")}</{name}>')
+                    f'{text}</{name}>')
 
         return outfile
 
 
-class Annotation(DataParser):
+class Annotation(object):
     """Additional descriptive information attached to an object"""
 
     def __init__(self, id_: str = None, title: str = None, type_: str = None,
-                 url: str = None, text: InternationalString = None,
-                 gds_collector=None):
-        super(Annotation, self).__init__(gds_collector_=gds_collector)
+                 url: str = None, text: InternationalString = None):
         self.id = id_
         self.title = title
         self.type = type_
@@ -224,70 +199,12 @@ class Annotation(DataParser):
     def text(self, value):
         self._text = value
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        value = find_attr_value_('id', node)
 
-        if value is not None and 'id' not in already_processed:
-            already_processed.add('id')
-            self._id = value
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the attributes present in the XML element"""
-        if nodeName_ == 'AnnotationTitle':
-            value_ = child_.text
-            value_ = self._gds_validate_string(value_)
-            self._title = value_
-        elif nodeName_ == 'AnnotationType':
-            value_ = child_.text
-            value_ = self._gds_validate_string(value_)
-            self._type = value_
-        elif nodeName_ == 'AnnotationURL':
-            value_ = child_.text
-            value_ = self._gds_validate_string(value_)
-            self._url = value_.strip()
-        elif nodeName_ == 'AnnotationText':
-            obj_ = LocalisedString._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            if self._text is None:
-                self._text = InternationalString()
-            self._text.addLocalisedString(obj_)
-
-
-class AnnotationsType(DataParser):
-    """Parser of the XML element Annotations"""
-
-    def __init__(self, gds_collector_=None):
-        super().__init__(gds_collector_)
-        self._annotations = []
-
-    @staticmethod
-    def _factory(*args_, **kwargs_):
-        """Factory Method of AnnotationsType"""
-        return AnnotationsType(*args_, **kwargs_)
-
-    @property
-    def annotations(self):
-        """The annotations included in the XML element Annotations"""
-        return self._annotations
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        if nodeName_ == 'Annotation':
-            obj_ = Annotation._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self._annotations.append(obj_)
-
-
-class AnnotableArtefact(DataParser):
+class AnnotableArtefact(object):
     """Superclass of all artefacts. Contains the list of annotations."""
 
-    def __init__(self, annotations: List[Annotation] = None,
-                 gds_collector=None):
+    def __init__(self, annotations: List[Annotation] = None):
 
-        super(AnnotableArtefact, self).__init__(gds_collector_=gds_collector)
         self._annotations = []
 
         if isinstance(annotations, list):
@@ -312,18 +229,9 @@ class AnnotableArtefact(DataParser):
     def addAnnotation(self, annotation: Annotation):
         """Method to add an annotation to the list"""
         if not isinstance(annotation, Annotation):
-            raise TypeError(
-                "Annotable artefacts can only get annotations as arguments")
-        else:
-            self._annotations.append(annotation)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        if nodeName_ == 'Annotations':
-            obj_ = AnnotationsType._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self._annotations = obj_.annotations
+            raise TypeError("Annotable artefacts can only get "
+                            "annotations as arguments")
+        self._annotations.append(annotation)
 
     def _to_XML(self, prettyprint):
 
@@ -366,8 +274,8 @@ class AnnotableArtefact(DataParser):
                 outfile.append(f'{child1}</{commonAbbr}:Annotation>')
             outfile.append(f'</{commonAbbr}:Annotations>')
             return outfile
-        else:
-            return None
+
+        return None
 
 
 class IdentifiableArtefact(AnnotableArtefact):
@@ -389,8 +297,7 @@ class IdentifiableArtefact(AnnotableArtefact):
             return (super(IdentifiableArtefact, self).__eq__(other) and
                     self._id == other._id and
                     self._uri == other._uri and self._urn == other._urn)
-        else:
-            return False
+        return False
 
     @property
     def id(self):
@@ -420,31 +327,6 @@ class IdentifiableArtefact(AnnotableArtefact):
     def urn(self, value):
         self._urn = generic_setter(value, str)
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        value = find_attr_value_('id', node)
-        if value is not None and 'id' not in already_processed:
-            already_processed.add('id')
-            self.id = value
-
-        value = find_attr_value_('uri', node)
-        if value is not None and 'uri' not in already_processed:
-            already_processed.add('uri')
-            self.uri = value
-
-        value = find_attr_value_('urn', node)
-        if value is not None and 'urn' not in already_processed:
-            already_processed.add('urn')
-            self.urn = value
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(IdentifiableArtefact, self)._build_children(child_, node,
-                                                          nodeName_,
-                                                          fromsubclass_,
-                                                          gds_collector_)
-
     def _to_XML(self, prettyprint) -> dict:
 
         attributes = ''
@@ -483,8 +365,7 @@ class NameableArtefact(IdentifiableArtefact):
             return (super(NameableArtefact, self).__eq__(other) and
                     self._name == other._name and
                     self._description == other._description)
-        else:
-            return False
+        return False
 
     @property
     def name(self):
@@ -492,16 +373,17 @@ class NameableArtefact(IdentifiableArtefact):
         the International String class """
         if self._name is None:
             return None
-        elif isinstance(self._name, InternationalString):
+        if isinstance(self._name, InternationalString):
             if len(self._name.items) == 0:
                 return None
-            elif len(self._name.items) == 1:
+            if len(self._name.items) == 1:
                 values_view = self._name.items.values()
                 value_iterator = iter(values_view)
                 first_value = next(value_iterator)
                 return first_value['content']
-            else:
-                return self._name.items
+
+            return self._name.items
+
         return self._name
 
     @property
@@ -510,16 +392,17 @@ class NameableArtefact(IdentifiableArtefact):
         via the International String class."""
         if self._description is None:
             return None
-        elif isinstance(self._description, InternationalString):
+        if isinstance(self._description, InternationalString):
             if len(self._description.items) == 0:
                 return None
-            elif len(self._description.items) == 1:
+
+            if len(self._description.items) == 1:
                 values_view = self._description.items.values()
                 value_iterator = iter(values_view)
                 first_value = next(value_iterator)
                 return first_value['content']
-            else:
-                return self._description.items
+
+            return self._description.items
         return self._description
 
     @name.setter
@@ -530,30 +413,6 @@ class NameableArtefact(IdentifiableArtefact):
     def description(self, value):
         self._description = generic_setter(value, InternationalString)
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(NameableArtefact, self)._build_attributes(node, attrs,
-                                                        already_processed)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(NameableArtefact, self)._build_children(child_, node, nodeName_,
-                                                      fromsubclass_,
-                                                      gds_collector_)
-        if nodeName_ == 'Name':
-            obj_ = LocalisedString._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            if self._name is None:
-                self._name = InternationalString()
-            self._name.addLocalisedString(obj_)
-        elif nodeName_ == 'Description':
-            obj_ = LocalisedString._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            if self._description is None:
-                self._description = InternationalString()
-            self._description.addLocalisedString(obj_)
-
     def _to_XML(self, prettyprint) -> dict:
         outfile = super(NameableArtefact, self)._to_XML(prettyprint)
 
@@ -591,8 +450,8 @@ class VersionableArtefact(NameableArtefact):
                     self._version == other._version and
                     self._validFrom == other._validFrom and
                     self._validTo == other._validTo)
-        else:
-            return False
+
+        return False
 
     @property
     def version(self):
@@ -615,43 +474,11 @@ class VersionableArtefact(NameableArtefact):
 
     @validFrom.setter
     def validFrom(self, value):
-        self._validFrom = set_date_from_string(value, "%Y-%m-%d")
-
-    #        self._validFrom = value
+        self._validFrom = set_date_from_string(value)
 
     @validTo.setter
     def validTo(self, value):
-        self._validTo = set_date_from_string(value, "%Y-%m-%d")
-        # self._validTo = value
-
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(VersionableArtefact, self)._build_attributes(node, attrs,
-                                                           already_processed)
-
-        value = find_attr_value_('version', node)
-        if value is not None and 'version' not in already_processed:
-            already_processed.add('version')
-            # TODO Validate version
-            self.version = value
-
-        value = find_attr_value_('validFrom', node)
-        if value is not None and 'validFrom' not in already_processed:
-            already_processed.add('validFrom')
-            self.validFrom = value
-
-        value = find_attr_value_('validTo', node)
-        if value is not None and 'validTo' not in already_processed:
-            already_processed.add('validTo')
-            self.validTo = value
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(VersionableArtefact, self)._build_children(child_, node,
-                                                         nodeName_,
-                                                         fromsubclass_,
-                                                         gds_collector_)
+        self._validTo = set_date_from_string(value)
 
     def _to_XML(self, prettyprint) -> dict:
         outfile = super(VersionableArtefact, self)._to_XML(prettyprint)
@@ -660,10 +487,12 @@ class VersionableArtefact(NameableArtefact):
             outfile['Attributes'] += f' version="{self.version}"'
 
         if self.validFrom is not None:
-            outfile['Attributes'] += f' validFrom="{self.validFrom}"'
+            valid_from_str = self.validFrom.strftime("%Y-%m-%dT%H:%M:%S")
+            outfile['Attributes'] += f' validFrom="{valid_from_str}"'
 
         if self.validTo is not None:
-            outfile['Attributes'] += f' validTo="{self.validTo}"'
+            valid_to_str = self.validTo.strftime("%Y-%m-%dT%H:%M:%S")
+            outfile['Attributes'] += f' validTo="{valid_to_str}"'
 
         return outfile
 
@@ -706,16 +535,15 @@ class MaintainableArtefact(VersionableArtefact):
                     self._serviceUrl == other._serviceUrl and
                     self._structureUrl == other._structureUrl and
                     self._maintainer == other._maintainer)
-        else:
-            return False
+        return False
 
     @property
     def unique_id(self):
         """Provides the unique id in the shape of AgencyID:ID(version)"""
         if isinstance(self.maintainer, str):
             return f'{self.maintainer}:{self.id}({self.version})'
-        else:
-            return f'{self.maintainer.id}:{self.id}({self.version})'
+
+        return f'{self.maintainer.id}:{self.id}({self.version})'
 
     @property
     def isFinal(self):
@@ -771,41 +599,10 @@ class MaintainableArtefact(VersionableArtefact):
         if self.maintainer is not None:
             if isinstance(self.maintainer, str):
                 return self.maintainer
-            else:
-                return self.maintainer.id
-        else:
-            return None
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(MaintainableArtefact, self)._build_attributes(node, attrs,
-                                                            already_processed)
+            return self.maintainer.id
 
-        value = find_attr_value_('agencyID', node)
-        if value is not None and 'agencyID' not in already_processed:
-            already_processed.add('agencyID')
-            self._maintainer = value
-
-        value = find_attr_value_('isExternalReference', node)
-        if value is not None and 'isExternalReference' not in \
-                already_processed:
-            already_processed.add('isExternalReference')
-            value = self._gds_parse_boolean(value)
-            self.isExternalReference = value
-
-        value = find_attr_value_('isFinal', node)
-        if value is not None and 'isFinal' not in already_processed:
-            already_processed.add('isFinal')
-            value = self._gds_parse_boolean(value)
-            self.isFinal = value
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(MaintainableArtefact, self)._build_children(child_, node,
-                                                          nodeName_,
-                                                          fromsubclass_,
-                                                          gds_collector_)
+        return None
 
     def _to_XML(self, prettyprint):
         outfile = super(MaintainableArtefact, self)._to_XML(prettyprint)
