@@ -10,24 +10,19 @@ from sdmxthon.model.base import MaintainableArtefact, \
     InternationalString
 from sdmxthon.model.component import Component
 from sdmxthon.model.descriptors import ComponentList, DimensionDescriptor, \
-    AttributeDescriptor, MeasureDescriptor, GroupDimensionDescriptor, \
-    StructureType, DataStructureComponentType
+    AttributeDescriptor, MeasureDescriptor, GroupDimensionDescriptor
 from sdmxthon.model.extras import ReferencePeriod, ReleaseCalendar
 from sdmxthon.model.utils import generic_setter, ConstraintRoleType, \
     bool_setter
-from sdmxthon.parsers.data_parser import DataParser
 from sdmxthon.utils.handlers import export_intern_data, add_indent, \
     split_unique_id
 from sdmxthon.utils.mappings import structureAbbr, Data_Types_VTL, commonAbbr
-from sdmxthon.utils.xml_base import find_attr_value_
 
 
-class MemberSelection(DataParser):
+class MemberSelection(object):
 
     def __init__(self, is_included: bool = False,
-                 values_for: Component = None, sel_value: list = None,
-                 gds_collector=None):
-        super(MemberSelection, self).__init__(gds_collector_=gds_collector)
+                 values_for: Component = None, sel_value: list = None):
         self.is_included = is_included
         self.values_for = values_for
         self.sel_value = []
@@ -53,7 +48,7 @@ class MemberSelection(DataParser):
 
     @values_for.setter
     def values_for(self, value):
-        self._values_for = generic_setter(value, Component)
+        self._values_for = generic_setter(value, str)
 
     @property
     def is_included(self):
@@ -63,32 +58,11 @@ class MemberSelection(DataParser):
     def is_included(self, value):
         self._is_included = bool_setter(value)
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        value = find_attr_value_('id', node)
-        if value is not None and 'id' not in already_processed:
-            already_processed.add('id')
-            self._values_for = value
 
-        value = find_attr_value_('include', node)
-        if value is not None and 'include' not in already_processed:
-            already_processed.add('include')
-            value = self._gds_parse_boolean(value)
-            self.is_included = value
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-
-        if nodeName_ == 'Value':
-            self.sel_value.append(child_.text)
-
-
-class CubeRegion(DataParser):
+class CubeRegion(object):
 
     def __init__(self, is_included: bool = False,
-                 member: MemberSelection = None, gds_collector=None):
-        super(CubeRegion, self).__init__(gds_collector_=gds_collector)
+                 member: List[MemberSelection] = None):
         self.is_included = is_included
 
         self.member = member
@@ -104,7 +78,7 @@ class CubeRegion(DataParser):
 
     @member.setter
     def member(self, value):
-        self._member = generic_setter(value, MemberSelection)
+        self._member = generic_setter(value, list)
 
     @property
     def is_included(self):
@@ -114,23 +88,6 @@ class CubeRegion(DataParser):
     def is_included(self, value):
         self._is_included = bool_setter(value)
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        value = find_attr_value_('include', node)
-        if value is not None and 'include' not in already_processed:
-            already_processed.add('include')
-            value = self._gds_parse_boolean(value)
-            self.is_included = value
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-
-        if nodeName_ == 'KeyValue':
-            obj_ = MemberSelection._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self.member = obj_
-
 
 class MetadataTargetRegion:
 
@@ -167,12 +124,9 @@ class MetadataTargetRegion:
         self._isIncluded = generic_setter(value, bool)
 
 
-class DataKeySet(DataParser):
-
-    def __init__(self, keys: list = None, isIncluded: bool = None,
-                 gds_collector=None):
-        super(DataKeySet, self).__init__(gds_collector_=gds_collector)
+class DataKeySet(object):
 
+    def __init__(self, keys: list = None, isIncluded: bool = None):
         self.keys = []
 
         if keys is not None:
@@ -201,41 +155,22 @@ class DataKeySet(DataParser):
     def is_included(self, value):
         self._isIncluded = bool_setter(value)
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        value = find_attr_value_('id', node)
-        if value is not None and 'id' not in already_processed:
-            already_processed.add('id')
-            self._valuesFor = value
-
-        value = find_attr_value_('isIncluded', node)
-        if value is not None and 'isIncluded' not in already_processed:
-            already_processed.add('isIncluded')
-            value = self._gds_parse_boolean(value)
-            self.is_included = value
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-
-        if nodeName_ == 'Key':
-            obj_ = KeySetType._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self.keys.append(obj_.key)
-
 
 class Constraint(MaintainableArtefact):
     def __init__(self, id_: str = None, uri: str = None, urn: str = None,
                  annotations=None,
                  name: InternationalString = None,
                  description: InternationalString = None,
-                 version: str = None, validFrom: datetime = None,
+                 version: str = None,
+                 maintainer=None,
+                 validFrom: datetime = None,
                  validTo: datetime = None,
-                 isFinal: bool = None, isExternalReference: bool = None,
+                 isFinal: bool = None,
+                 isExternalReference: bool = None,
                  serviceUrl: str = None,
                  structureUrl: str = None,
                  dataContentRegion: List[CubeRegion] = None,
-                 dataContentKeys: DataKeySet = None,
+                 dataKeySet: List[DataKeySet] = None,
                  metadataContentRegion: List[MetadataTargetRegion] = None,
                  availableDates: List[ReferencePeriod] = None,
                  calendar: List[ReleaseCalendar] = None):
@@ -248,6 +183,7 @@ class Constraint(MaintainableArtefact):
                      version=version, validFrom=validFrom,
                      validTo=validTo,
                      isFinal=isFinal,
+                     maintainer=maintainer,
                      isExternalReference=isExternalReference,
                      serviceUrl=serviceUrl,
                      structureUrl=structureUrl)
@@ -266,7 +202,7 @@ class Constraint(MaintainableArtefact):
         if calendar is not None:
             self.calendar = calendar
 
-        self.data_content_keys = dataContentKeys
+        self.data_content_keys = dataKeySet
 
         self._ref_attach = None
         self._type_attach = None
@@ -285,7 +221,7 @@ class Constraint(MaintainableArtefact):
 
     @data_content_keys.setter
     def data_content_keys(self, value):
-        self._data_content_keys = generic_setter(value, DataKeySet)
+        self._data_content_keys = generic_setter(value, list)
 
     @property
     def metadata_content_region(self):
@@ -319,102 +255,30 @@ class Constraint(MaintainableArtefact):
     def type_attach(self):
         return self._type_attach
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(Constraint, self)._build_attributes(node, attrs,
-                                                  already_processed)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(Constraint, self)._build_children(child_, node, nodeName_,
-                                                fromsubclass_, gds_collector_)
-
-        if nodeName_ == 'ConstraintAttachment':
-            obj_ = AttachmentConstraintType._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self._ref_attach = obj_.ref
-            self._type_attach = obj_.type_
-
-        elif nodeName_ == 'CubeRegion':
-            obj_ = CubeRegion._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self.data_content_region.append(obj_)
-
-        elif nodeName_ == 'DataKeySet':
-            obj_ = DataKeySet._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self.data_content_keys = obj_
-
-
-class AttachmentConstraintType(DataParser):
-
-    def __init__(self, gds_collector=None):
-        super(AttachmentConstraintType, self).__init__(
-            gds_collector_=gds_collector)
-        self._ref = None
-        self._type = None
-
-    @staticmethod
-    def _factory(*args_, **kwargs_):
-        """Factory Method of AttachmentConstraintType"""
-        return AttachmentConstraintType(*args_, **kwargs_)
-
-    @property
-    def ref(self):
-        return self._ref
-
-    @property
-    def type_(self):
-        return self._type
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-
-        if nodeName_ == 'Dataflow' or nodeName_ == 'DataStructure':
-            obj_ = StructureType._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self._ref = obj_.ref
-            self._type = nodeName_
-
-
-class KeySetType(DataParser):
-    def __init__(self, gds_collector=None):
-        super(KeySetType, self).__init__(gds_collector_=gds_collector)
 
+class KeySetType(object):
+    def __init__(self):
         self._key = {}
 
-    @staticmethod
-    def _factory(*args_, **kwargs_):
-        """Factory Method of KeySetType"""
-        return KeySetType(*args_, **kwargs_)
-
     @property
     def key(self):
         return self._key
 
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-
-        if nodeName_ == 'KeyValue':
-            obj_ = MemberSelection._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self._key[obj_.values_for] = obj_.sel_value[0]
-
 
 class ContentConstraint(Constraint):
     def __init__(self, id_: str = None, uri: str = None, urn: str = None,
                  annotations=None,
                  name: InternationalString = None,
                  description: InternationalString = None,
-                 version: str = None, validFrom: datetime = None,
+                 version: str = None,
+                 maintainer=None,
+                 validFrom: datetime = None,
                  validTo: datetime = None,
                  isFinal: bool = None, isExternalReference: bool = None,
                  serviceUrl: str = None,
                  structureUrl: str = None,
                  dataContentRegion: List[CubeRegion] = None,
+                 dataKeySet: List[DataKeySet] = None,
                  metadataContentRegion: List[MetadataTargetRegion] = None,
                  availableDates: List[ReferencePeriod] = None,
                  calendar: List[ReleaseCalendar] = None,
@@ -427,6 +291,7 @@ class ContentConstraint(Constraint):
                      name=name,
                      description=description,
                      version=version,
+                     maintainer=maintainer,
                      validFrom=validFrom,
                      validTo=validTo,
                      isFinal=isFinal,
@@ -434,6 +299,7 @@ class ContentConstraint(Constraint):
                      serviceUrl=serviceUrl,
                      structureUrl=structureUrl,
                      dataContentRegion=dataContentRegion,
+                     dataKeySet=dataKeySet,
                      metadataContentRegion=metadataContentRegion,
                      availableDates=availableDates,
                      calendar=calendar)
@@ -442,11 +308,6 @@ class ContentConstraint(Constraint):
                              '"allowableContent" or "actualContent"')
         self._role = role
 
-    @staticmethod
-    def _factory(*args_, **kwargs_):
-        """Factory Method of ContentConstraint"""
-        return ContentConstraint(*args_, **kwargs_)
-
     @property
     def role(self):
         return self._role
@@ -456,25 +317,7 @@ class ContentConstraint(Constraint):
         if value not in ConstraintRoleType:
             raise ValueError('ConstraintRole must be either '
                              '"Allowed" or "Actual"')
-        else:
-            self._role = value
-
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(ContentConstraint, self)._build_attributes(node, attrs,
-                                                         already_processed)
-
-        value = find_attr_value_('type', node)
-        if value is not None and 'type' not in already_processed:
-            already_processed.add('type')
-            self.role = value
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(ContentConstraint, self)._build_children(child_, node, nodeName_,
-                                                       fromsubclass_,
-                                                       gds_collector_)
+        self._role = value
 
     def _parse_XML(self, indent, label):
         prettyprint = indent != ''
@@ -513,35 +356,37 @@ class ContentConstraint(Constraint):
         outfile += f'{indent_child}</{structureAbbr}:ConstraintAttachment>'
 
         if self.data_content_keys is not None:
+            for i in self.data_content_keys:
+                outfile += f'{indent_child}<{structureAbbr}:DataKeySet ' \
+                           f'isIncluded="' \
+                           f'{str(i.is_included).lower()}">'
 
-            outfile += f'{indent_child}<{structureAbbr}:DataKeySet ' \
-                       f'isIncluded="' \
-                       f'{str(self.data_content_keys.is_included).lower()}">'
+                for e in i.keys:
+                    outfile += f'{indent_child_2}<{structureAbbr}:Key>'
 
-            for e in self.data_content_keys.keys:
-                outfile += f'{indent_child_2}<{structureAbbr}:Key>'
+                    for k, v in e.items():
+                        outfile += f'{indent_ref}<{commonAbbr}:KeyValue ' \
+                                   f'id="{k}">'
+                        outfile += f'{indent_value}<{commonAbbr}:Value>{v}' \
+                                   f'</{commonAbbr}:Value>'
+                        outfile += f'{indent_ref}</{commonAbbr}:KeyValue>'
 
-                for k, v in e.items():
-                    outfile += f'{indent_ref}<{commonAbbr}:KeyValue id="{k}">'
-                    outfile += f'{indent_value}<{commonAbbr}:Value>{v}' \
-                               f'</{commonAbbr}:Value>'
-                    outfile += f'{indent_ref}</{commonAbbr}:KeyValue>'
+                    outfile += f'{indent_child_2}</{structureAbbr}:Key>'
 
-                outfile += f'{indent_child_2}</{structureAbbr}:Key>'
-
-            outfile += f'{indent_child}</{structureAbbr}:DataKeySet>'
+                outfile += f'{indent_child}</{structureAbbr}:DataKeySet>'
 
         if self.data_content_region is not None:
 
             for e in self.data_content_region:
                 outfile += f'{indent_child}<{structureAbbr}:CubeRegion ' \
                            f'isIncluded="{str(e.is_included).lower()}">'
-                outfile += f'{indent_child_2}<{commonAbbr}:KeyValue ' \
-                           f'id="{e.member.values_for}">'
-                for j in e.member.sel_value:
-                    outfile += f'{indent_ref}<{commonAbbr}:Value>{j}' \
-                               f'</{commonAbbr}:Value>'
-                outfile += f'{indent_child_2}</{commonAbbr}:KeyValue>'
+                for m in e.member:
+                    outfile += f'{indent_child_2}<{commonAbbr}:KeyValue ' \
+                               f'id="{m.values_for}">'
+                    for j in m.sel_value:
+                        outfile += f'{indent_ref}<{commonAbbr}:Value>{j}' \
+                                   f'</{commonAbbr}:Value>'
+                    outfile += f'{indent_child_2}</{commonAbbr}:KeyValue>'
                 outfile += f'{indent_child}</{structureAbbr}:CubeRegion>'
 
         outfile += f'{indent}</{label}>'
@@ -549,6 +394,19 @@ class ContentConstraint(Constraint):
         return outfile
 
 
+def add_type_facets(key, value, type_, facets):
+    if value.representation is not None:
+        if value.representation.type_ is not None:
+            type_[key] = value.representation.type_
+        else:
+            type_[key] = 'String'
+
+        if len(value.representation.facets) > 0:
+            facets[key] = value.representation.facets
+    else:
+        type_[key] = 'String'
+
+
 class DataStructureDefinition(MaintainableArtefact):
     """A collection of metadata concepts, their structure and usage when used
     to collect or disseminate data."""
@@ -562,10 +420,10 @@ class DataStructureDefinition(MaintainableArtefact):
                  isFinal: bool = None, isExternalReference: bool = None,
                  serviceUrl: str = None,
                  structureUrl: str = None, maintainer=None,
-                 dimensionDescriptor: DimensionDescriptor = None,
-                 measureDescriptor: MeasureDescriptor = None,
-                 attributeDescriptor: AttributeDescriptor = None,
-                 groupDimensionDescriptor: GroupDimensionDescriptor = None,
+                 dimension_list: DimensionDescriptor = None,
+                 measure_list: MeasureDescriptor = None,
+                 attribute_list: AttributeDescriptor = None,
+                 group_dimension_descriptor: GroupDimensionDescriptor = None,
                  constraint: list = None):
 
         super(DataStructureDefinition, self). \
@@ -583,10 +441,10 @@ class DataStructureDefinition(MaintainableArtefact):
                      structureUrl=structureUrl,
                      maintainer=maintainer)
 
-        self.dimension_descriptor = dimensionDescriptor
-        self.measure_descriptor = measureDescriptor
-        self.attribute_descriptor = attributeDescriptor
-        self.group_dimension_descriptor = groupDimensionDescriptor
+        self.dimension_descriptor = dimension_list
+        self.measure_descriptor = measure_list
+        self.attribute_descriptor = attribute_list
+        self.group_dimension_descriptor = group_dimension_descriptor
         self._constraints = constraint
 
     def __eq__(self, other):
@@ -597,8 +455,8 @@ class DataStructureDefinition(MaintainableArtefact):
                     self._measureDescriptor == other._measureDescriptor and
                     self._groupDimensionDescriptor ==
                     other._groupDimensionDescriptor)
-        else:
-            return False
+
+        return False
 
     def __str__(self):
         return '<DataStructureDefinition  - %s:%s(%s)>' % (
@@ -612,11 +470,6 @@ class DataStructureDefinition(MaintainableArtefact):
         return '<DataStructureDefinition  - %s:%s(%s)>' % (
             self.agencyID, self.id, self.version)
 
-    @staticmethod
-    def _factory(*args_, **kwargs_):
-        """Factory Method of DataStructureDefinition"""
-        return DataStructureDefinition(*args_, **kwargs_)
-
     @property
     def dimension_descriptor(self):
         """An ordered set of metadata concepts that, combined, classify a
@@ -653,8 +506,8 @@ class DataStructureDefinition(MaintainableArtefact):
         """Keys of the attributeDescriptor components"""
         if self.attribute_descriptor is not None:
             return [k for k in self.attribute_descriptor.components]
-        else:
-            return []
+
+        return []
 
     @property
     def dataset_attribute_codes(self):
@@ -690,30 +543,15 @@ class DataStructureDefinition(MaintainableArtefact):
         facets = {}
         type_ = {}
         for k, v in self.dimension_descriptor.components.items():
-            if v.representation is not None:
-                if v.representation.type_ is not None:
-                    type_[k] = v.representation.type_
-
-                if len(v.representation.facets) > 0:
-                    facets[k] = v.representation.facets
+            add_type_facets(k, v, type_, facets)
 
         if self.attribute_descriptor is not None:
             for k, v in self.attribute_descriptor.components.items():
-                if v.representation is not None:
-                    if v.representation.type_ is not None:
-                        type_[k] = v.representation.type_
-
-                    if len(v.representation.facets) > 0:
-                        facets[k] = v.representation.facets
+                add_type_facets(k, v, type_, facets)
 
         if self.measure_descriptor is not None:
             for k, v in self.measure_descriptor.components.items():
-                if v.representation is not None:
-                    if v.representation.type_ is not None:
-                        type_[k] = v.representation.type_
-
-                    if len(v.representation.facets) > 0:
-                        facets[k] = v.representation.facets
+                add_type_facets(k, v, type_, facets)
 
         return facets, type_
 
@@ -727,16 +565,18 @@ class DataStructureDefinition(MaintainableArtefact):
             for c in self.constraints:
                 if len(c.data_content_region) > 0:
                     for e in c.data_content_region:
-                        if e.member.values_for not in cubes.keys():
-                            cubes[e.member.values_for] = set(
-                                e.member.sel_value)
-                        else:
-                            cubes[e.member.values_for].update(
-                                e.member.sel_value)
-                if c.data_content_keys is not None and \
-                        c.role is not None and \
-                        c.role == "Allowed":
-                    series += c.data_content_keys.keys
+                        for m in e.member:
+                            if m.values_for not in cubes.keys():
+                                cubes[m.values_for] = set(
+                                    m.sel_value)
+                            else:
+                                cubes[m.values_for].update(
+                                    m.sel_value)
+                if (c.data_content_keys is not None and
+                        len(c.data_content_keys) > 0):
+                    for e in c.data_content_keys:
+                        if c.role is not None and c.role == "Allowed":
+                            series += e.keys
 
         return cubes, series
 
@@ -819,26 +659,6 @@ class DataStructureDefinition(MaintainableArtefact):
         else:
             return result
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(DataStructureDefinition, self). \
-            _build_attributes(node, attrs, already_processed)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(DataStructureDefinition, self). \
-            _build_children(child_, node, nodeName_, fromsubclass_,
-                            gds_collector_)
-
-        if nodeName_ == 'DataStructureComponents':
-            obj_ = DataStructureComponentType._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self.attribute_descriptor = obj_.attributeDescriptor
-            self.dimension_descriptor = obj_.dimensionDescriptor
-            self.measure_descriptor = obj_.measureDescriptor
-            self.group_dimension_descriptor = obj_.groupDimensionDescriptor
-
     def _parse_XML(self, indent, label):
         prettyprint = indent != ''
 
@@ -914,8 +734,10 @@ class DataFlowDefinition(MaintainableArtefact):
 
     def __eq__(self, other):
         if isinstance(other, DataFlowDefinition):
-            return super(DataFlowDefinition, self).__eq__(
-                other) and self._structure == other._structure
+            return (super(DataFlowDefinition, self).__eq__(other) and
+                    self._structure == other._structure)
+
+        return False
 
     def __str__(self):
         return f'<DataFlowDefinition - {self.unique_id}>'
@@ -941,25 +763,10 @@ class DataFlowDefinition(MaintainableArtefact):
         self._structure = generic_setter(value, DataStructureDefinition)
 
     def add_constraint(self, value: ContentConstraint):
+        if self._constraints is None:
+            self._constraints = []
         self._constraints.append(value)
 
-    def _build_attributes(self, node, attrs, already_processed):
-        """Builds the attributes present in the XML element"""
-        super(DataFlowDefinition, self)._build_attributes(node, attrs,
-                                                          already_processed)
-
-    def _build_children(self, child_, node, nodeName_, fromsubclass_=False,
-                        gds_collector_=None):
-        """Builds the childs of the XML element"""
-        super(DataFlowDefinition, self)._build_children(child_, node,
-                                                        nodeName_,
-                                                        fromsubclass_=False,
-                                                        gds_collector_=None)
-        if nodeName_ == 'Structure':
-            obj_ = StructureType._factory()
-            obj_._build(child_, gds_collector_=gds_collector_)
-            self._structure = obj_.ref
-
     def _parse_XML(self, indent, label):
         prettyprint = indent != ''
 
